(publish-all-diagnostics! uris publish-empty? {:keys [db*] :as components})(publish-all-diagnostics-directly! uris publish-empty? {:keys [db* producer]})Publishes diagnostics for all uris straight to the producer, bypassing the debounced diagnostics channel. Suited for one-shot bulk publishes such as startup, where the per-uri debounce only adds latency.
Publishes diagnostics for all uris straight to the producer, bypassing the debounced diagnostics channel. Suited for one-shot bulk publishes such as startup, where the per-uri debounce only adds latency.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |